@@ -2,7 +2,7 @@
 import sys
 
 
-__version__ = '4.5.0'
+__version__ = '5.2.0'
 
 API_PATH = {
     'about_edited':           'r/{subreddit}/about/edited/',
@@ -18,6 +18,7 @@ API_PATH = {
     'approve':                'api/approve/',
     'block':                  'api/block',
     'blocked':                'prefs/blocked/',
+    'collapse':               'api/collapse_message/',
     'comment':                'api/comment/',
     'comment_replies':        'message/comments/',
     'compose':                'api/compose/',
@@ -52,6 +53,7 @@ API_PATH = {
     'karma':                  'api/v1/me/karma',
     'leavecontributor':       'api/leavecontributor',
     'leavemoderator':         'api/leavemoderator',
+    'link_flair':             'r/{subreddit}/api/link_flair',
     'list_banned':            'r/{subreddit}/about/banned/',
     'list_contributor':       'r/{subreddit}/about/contributors/',
     'list_moderator':         'r/{subreddit}/about/moderators/',
@@ -63,6 +65,7 @@ API_PATH = {
     'live_close':             'api/live/{id}/close_thread',
     'live_contributors':      'live/{id}/contributors',
     'live_discussions':       'live/{id}/discussions',
+    'live_focus':             'live/{thread_id}/updates/{update_id}',
     'live_info':              'api/live/by_id/{ids}',
     'live_invite':            'api/live/{id}/invite_contributor',
     'live_leave':             'api/live/{id}/leave_contributor',
@@ -119,6 +122,7 @@ API_PATH = {
     'save':                   'api/save/',
     'search':                 'r/{subreddit}/search/',
     'select_flair':           'r/{subreddit}/api/selectflair/',
+    'sendreplies':            'api/sendreplies',
     'sent':                   'message/sent/',
     'setpermissions':         'r/{subreddit}/api/setpermissions/',
     'spoiler':                'api/spoiler/',
@@ -145,6 +149,7 @@ API_PATH = {
     'subreddits_search':      'subreddits/search/',
     'subscribe':              'api/subscribe/',
     'suggested_sort':         'api/set_suggested_sort/',
+    'uncollapse':             'api/uncollapse_message/',
     'unfriend':               'r/{subreddit}/api/unfriend/',
     'unhide':                 'api/unhide/',
     'unignore_reports':       'api/unignore_reports/',
